from setuptools import setup, find_packages
from pip_tools import get_last_release_version, get_last_prerelease_version

VERSION = '1.1.0.dev5'

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

if 'dev' in VERSION:
    RAYA_VERSION = get_last_prerelease_version('raya')
else:
    RAYA_VERSION = get_last_release_version('raya')

setup(
    name='rayasdk',
    packages=find_packages(),
    version=VERSION,
    license='MIT',
    description='Raya SDK - Unlimited Robotics Software Development Kit',
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='Unlimited Robotics',
    author_email='camilo@unlimited-robotics.com',
    url='',
    python_requires=">=3.8",
    download_url='',
    package_data={'': ['./template/*']},
    keywords=['robotics', 'unlimited-robotics', 'gary'],
    install_requires=[
        f'raya=={RAYA_VERSION}',
        'tabulate', 
        'importlib_metadata', 
        'tqdm', 
        'docker', 
        'progressbar',
        'simple_file_checksum', 
        'gsutil', 
        'zeroconf', 
        'paramiko',
    ],
    entry_points={
        'console_scripts': [
            'rayasdk = rayasdk.__main__:main',
        ],
    },
)
